The Moola optimisation package
==============================

Moola implements a set of optimisation algorithms with a special focus on PDE-constrained optimisation problems.

You need to have FEniCS_ and dolfin-adjoint_ installed to run the tests.


.. _FEniCS: http://www.fenicsproject.org
.. _dolfin-adjoint: http://dolfin-adjoint.org


Installation
------------

    pip install git+https://github.com/funsim/moola.git@master

License
_______

Moola is freely available under the GNU LGPL, version 3.
